# Reference: https://github.com/eklitzke/bitcoin-rpm/blob/master/bitcoin.spec

Name:    bitcoin-satellite
Version: 25.0.0.2.4
Release: 1%{?dist}
Summary: Bitcoin with support for Blockstream Satellite
Group:   Applications/System
License: MIT
URL:     https://github.com/Blockstream/bitcoinsatellite
Source0: %{name}-%{version}.tar.gz

%if 0%{?fedora} >= 26
%global __brp_remove_la_files %nil
%endif

%if 0%{?rhel} == 7
BuildRequires: epel-release
BuildRequires: centos-release-scl
BuildRequires: devtoolset-8
%endif
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: libtool
BuildRequires: make
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: openssl-devel
BuildRequires: libevent-devel
BuildRequires: python3
BuildRequires: boost-devel
BuildRequires: zeromq-devel
BuildRequires: sqlite-devel
%if 0%{?rhel} != 8
BuildRequires: miniupnpc-devel
# miniupnpc-devel is not available on el8, so UPnP support will be disabled.
%endif
# Require libdb4 for wallet support
BuildRequires: libdb4-devel
BuildRequires: libdb4-cxx-devel

%description
Bitcoin Satellite is a fork from FIBRE (Fast Internet Bitcoin Relay Engine) and,
consequently, also a fork of Bitcoin Core. It features a version of the bitcoind
application with support for satellite-optimized one-way transport of blocks
sent over UDP with multicast addressing. It is designed to be used by the
transmitters and receivers of the Blockstream Satellite network.

%package qt
Summary:        Bitcoin with support for Blockstream Satellite
Group:          Applications/System
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}
BuildRequires: qt5-qttools-devel
BuildRequires: qt5-qtbase-devel
BuildRequires: protobuf-devel
BuildRequires: qrencode-devel
BuildRequires: desktop-file-utils

%description qt
This package contains the Qt based graphical client and node.

%package libs
Summary:        Bitcoin shared libraries
Group:          System Environment/Libraries

%description libs
This package provides the bitcoinconsensus shared libraries. These libraries
may be used by third party software to provide consensus verification
functionality.

%package devel
Summary:        Development files for bitcoin
Group:          Development/Libraries
Requires:       %{name}-libs = %{version}-%{release}

%description devel
This package contains the header files and static library for the
bitcoinconsensus shared library. If you are developing or compiling software
that wants to link against that library, then you need this package installed.

%prep
%autosetup -n %{name}-%{version}

%define configargs --enable-glibc-back-compat --enable-reduce-exports --disable-bench

%build
./autogen.sh
%if 0%{?rhel} == 7
# Compile using the gcc version from devtoolset-8 on el7
scl enable devtoolset-8 './configure %{?configargs} --prefix=/usr --libdir=%{_libdir}'
scl enable devtoolset-8 '%make_build'
%else
./configure %{?configargs} --prefix=/usr --libdir=%{_libdir}
%make_build
%endif

%check
export LC_ALL=C.UTF-8 make check

%install
%make_install
# no need to generate debuginfo data for the test executables
rm -f %{buildroot}%{_bindir}/test_bitcoin*
# qt icons
install -D -p share/pixmaps/bitcoin.ico %{buildroot}%{_datadir}/pixmaps/bitcoin.ico

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%license COPYING
%doc COPYING doc/README.md doc/REST-interface.md doc/bips.md doc/dnsseed-policy.md doc/files.md doc/reduce-traffic.md doc/release-notes.md doc/tor.md
%attr(0755,root,root) %{_bindir}/bitcoind
%attr(0755,root,root) %{_bindir}/bitcoin-cli
%attr(0755,root,root) %{_bindir}/bitcoin-tx
%attr(0755,root,root) %{_bindir}/bitcoin-util
%attr(0755,root,root) %{_bindir}/bitcoin-wallet
%attr(0644,root,root) %{_mandir}/man1/bitcoind.1*
%attr(0644,root,root) %{_mandir}/man1/bitcoin-cli.1*
%attr(0644,root,root) %{_mandir}/man1/bitcoin-tx.1*
%attr(0644,root,root) %{_mandir}/man1/bitcoin-util.1*
%attr(0644,root,root) %{_mandir}/man1/bitcoin-wallet.1*

%files qt
%defattr(-,root,root,-)
%license COPYING
%doc COPYING doc/README.md doc/bips.md doc/files.md doc/reduce-traffic.md doc/release-notes.md doc/tor.md
%attr(0755,root,root) %{_bindir}/bitcoin-qt
%attr(0644,root,root) %{_datadir}/pixmaps/*.ico
%attr(0644,root,root) %{_mandir}/man1/bitcoin-qt.1*

%files libs
%defattr(-,root,root,-)
%license COPYING
%doc COPYING doc/README.md doc/shared-libraries.md
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root,-)
%license COPYING
%doc COPYING doc/README.md doc/developer-notes.md doc/shared-libraries.md
%attr(0644,root,root) %{_includedir}/*.h
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/*.la
%attr(0644,root,root) %{_libdir}/pkgconfig/*.pc

